s3_file_download downloads AWS S3 files to local
s3_file_download downloads AWS s3 directory to local
s3_file_download_async(path, new_path, overwrite = FALSE, ...)s3_dir_download_async(path, new_path, overwrite = FALSE, ...)
return future object of s3_file_download()
s3_dir_download()
(character): A character vector of paths or uris
(character): A character vector of paths to the new locations.
(logical): Overwrite files if the exist. If this is FALSE
and the file exists an error will be thrown.
parameters to be passed to s3_get_object
future s3_file_download() s3_dir_download()